@@ -3,7 +3,7 @@
 """
 Implementation of the `core` command-line front-ends.
 """
-# Copyright (C) 2009-2012 GC3, University of Zurich. All rights reserved.
+# Copyright (C) 2009-2013 GC3, University of Zurich. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -20,7 +20,7 @@ Implementation of the `core` command-line front-ends.
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
 __docformat__ = 'reStructuredText'
-__version__ = '2.0.1 version (SVN $Revision: 3196 $)'
+__version__ = '2.0.2 version (SVN $Revision: 3354 $)'
 __author__ = "Sergio Maffioletti <sergio.maffioletti@gc3.uzh.ch>, "
 "Riccardo Murri <riccardo.murri@uzh.ch>"
 "Antonio Messina <arcimboldo@gmail.com>"
@@ -960,11 +960,10 @@ To get detaileid info on a specific command, run:
                 task.kill()
             except Exception, ex:
                 gc3libs.log.error(
-                    "Failed while killing job '%s'"
+                    "Failed killing job '%s'"
                     "Error type %s, message %s" % (ex.__class__, ex))
-            finally:
-                task.free()
-                rc += 1
+            task.free()
+            rc += 1
             self.session.remove(task_id)
 
         if self.session.tasks:
@@ -1017,7 +1016,7 @@ To get detaileid info on a specific command, run:
                 jobname = app.jobname
             except AttributeError:
                 jobname = ''
-            
+
             rows.append([indent + app.persistent_id,
                          jobname,
                          app.execution.state,
